import { nameof } from "ts-simple-nameof";
import { LogLevel } from "./ILoggerService";
var LoggerService = (function () {
    function LoggerService() {
        this._blockedServices = [];
        this._logLevel = LogLevel.Debug;
    }
    LoggerService.prototype.GetNameOf = function (service) {
        if (service != null && (typeof service === 'string' || service instanceof String))
            return "".concat(service);
        else
            return nameof(service);
    };
    LoggerService.prototype.IsBlocked = function (service) {
        if (service === undefined)
            return false;
        var name = "";
        if (service != null) {
            if (typeof service === 'string' || service instanceof String)
                name = this.GetNameOf("".concat(service));
            else
                name = this.GetNameOf(service);
        }
        return this._blockedServices.any(function (a) { return a == name; });
    };
    LoggerService.prototype.DisableLogsFrom = function (service) {
        var name = this.GetNameOf(service);
        if (this._blockedServices.all(function (a) { return a != name; }))
            this._blockedServices.push(name);
    };
    LoggerService.prototype.EnableLogsFrom = function (service) {
        var name = this.GetNameOf(service);
        if (this._blockedServices.any(function (a) { return a == name; }))
            this._blockedServices = this._blockedServices.where(function (a) { return a != name; }).toArray();
    };
    Object.defineProperty(LoggerService.prototype, "LogLevel", {
        get: function () {
            return this._logLevel;
        },
        set: function (level) {
            this._logLevel = level;
        },
        enumerable: false,
        configurable: true
    });
    LoggerService.prototype.GetServiceName = function () {
        return nameof(LoggerService);
    };
    LoggerService.prototype.GetTimeStamp = function () {
        var date = new Date();
        return "".concat(date.getHours(), ":").concat(date.getMinutes(), ":").concat(date.getSeconds(), ".").concat(date.getMilliseconds(), " | ");
    };
    LoggerService.prototype.Warning = function (contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Warning:
            case LogLevel.Info:
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (this.IsBlocked(contextClassType))
            return;
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.warn("".concat(this.GetTimeStamp(), "[WARN] ").concat(contextClassType));
            else
                console.warn("".concat(this.GetTimeStamp(), "[WARN] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.warn("".concat(this.GetTimeStamp(), "[WARN] [").concat(nameof(contextClassType), "] ").concat(message));
    };
    LoggerService.prototype.Error = function (contextClassType, message) {
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.error("".concat(this.GetTimeStamp(), "[ERROR] ").concat(contextClassType));
            else
                console.error("".concat(this.GetTimeStamp(), "[ERROR] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.error("".concat(this.GetTimeStamp(), "[ERROR] [").concat(nameof(contextClassType), "] ").concat(message));
    };
    LoggerService.prototype.Info = function (contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Info:
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (this.IsBlocked(contextClassType))
            return;
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.info("".concat(this.GetTimeStamp(), "[INFO] ").concat(contextClassType));
            else
                console.info("".concat(this.GetTimeStamp(), "[INFO] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.info("".concat(this.GetTimeStamp(), "[INFO] [").concat(nameof(contextClassType), "] ").concat(message));
    };
    LoggerService.prototype.Debug = function (contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (this.IsBlocked(contextClassType))
            return;
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.debug("".concat(this.GetTimeStamp(), "[DEBUG] ").concat(contextClassType));
            else
                console.debug("".concat(this.GetTimeStamp(), "[DEBUG] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.debug("".concat(this.GetTimeStamp(), "[DEBUG] [").concat(nameof(contextClassType), "] ").concat(message));
    };
    LoggerService.prototype.Log = function (contextClassType, message) {
        if (this.IsBlocked(contextClassType))
            return;
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            if (message === null || message === undefined)
                console.log("".concat(this.GetTimeStamp(), "[LOG] ").concat(contextClassType));
            else
                console.log("".concat(this.GetTimeStamp(), "[LOG] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.log("".concat(this.GetTimeStamp(), "[LOG] [").concat(nameof(contextClassType), "] ").concat(message));
    };
    return LoggerService;
}());
export { LoggerService };
//# sourceMappingURL=LoggerService.js.map